#
# Written by Il-Chul Yoon <iyoon@cs.umd.edu>

package show_rc_select;

use PerlDB;
use utilfunc;
use Data::Dumper;
use strict;

sub new {
    my $classname  = shift;         # What class are we constructing?
    my $self   = {};                # Allocate new memory
    bless($self, $classname);       # Mark it of the right type
    return $self;
}

sub showContents {
    my $self = shift;
    my $cgi = shift;
        
    print "<center>".$cgi->h1('Search Result')."</center>";

    print $cgi->h3('Select Resources to remove');

    #&utilfunc::print_params($cgi);

    my $rctype = $cgi->param('rctype');

	# retrieve selectively from database using SQL pattern matching.
	# modify the regular expression mark to MySQL pattern matching style.
	my $rcname = $cgi->param('rcname');

   if(length(&utilfunc::trimwhitespace($rcname)) == 0){
      print "Resource name is necessary";
      return -1;
   }

	$rcname =~ s/\*/%/g;
	$rcname =~ s/\?/_/g;

    if($rctype eq "cluster"){
        &showCluster($cgi, $rctype, $rcname);
    }
    elsif($rctype eq "node"){
        &showNode($cgi, $rctype, $rcname);
    }
    elsif($rctype eq "manager"){
        &showManager($cgi, $rctype, $rcname);
    }
}

sub showCluster {
    my ($cgi, $rctype, $rcname) = @_;

    # Query to selected database    	
    my $perldb = new PerlDB();
    my $query = "SELECT cluster_id, clst_name, scheduler, mgr_host
                 FROM resource, rcmgr, cluster 
                 WHERE resource.rc_id=cluster.rc_id and rcmgr.mgr_id=resource.mgr_id and
                       clst_name LIKE '$rcname'";
    my @rcarray = @{$perldb->multcol_select($query)};
    $perldb->db_end ;

    # Show resources in Form
    print $cgi->start_form(-name=>'rctable',
                           -onsubmit=>"return validate_atleastone_rc_checked(this)");

    print $cgi->hidden(-name=>'rctype', -default=>$cgi->param('rctype'));
    print $cgi->hidden(-name=>'mode', -default=>"select");
                           
    print $cgi->start_table({-border => 1});
    print $cgi->start_Tr({-align=>'center', -valign=>'middle'});
    print $cgi->td("Select");
    print $cgi->td($cgi->a({-href=>"https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_cluster.html", 
                            -onClick=>"return popup('https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_cluster.html')"},
                           "ClusterName"));
    print $cgi->td($cgi->a({-href=>"https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_sched.html", 
                            -onClick=>"return popup('https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_sched.html')"},
                           "Scheduler"));
    print $cgi->td($cgi->a({-href=>"https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_clusterhead.html", 
                            -onClick=>"return popup('https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_clusterhead.html')"},
                           "Cluster Head"));
    print $cgi->end_Tr;

    foreach(@rcarray){
        print $cgi->start_Tr({-align=>'center', -valign=>'middle'});

        my $identifier = "$_->[0]"; # cluster_id in cluster table
        print $cgi->td($cgi->checkbox(-name=>"cluster.choice.$identifier",
                                      -checked=>0,
                                      -value=>1,
                                      -label=>'')); # selection checkbox
        print $cgi->td($_->[1]);
        print $cgi->td($_->[2]);
        print $cgi->td($_->[3]);
        
        $cgi->end_Tr();
    }

    print $cgi->end_table;
    print "<br>";
    print $cgi->submit(-value=>'Remove Selected Resources');
    print $cgi->end_form;
}


sub showNode {
    my ($cgi, $rctype, $rcname) = @_;

    # Query to selected database    	
    my $perldb = new PerlDB();
    my $query = "SELECT node_id, node_name, domain
                 FROM resource, node 
                 WHERE resource.rc_id=node.rc_id and node_name LIKE '$rcname'";
    my @rcarray = @{$perldb->multcol_select($query)};
    $perldb->db_end ;

    # Show resources in Form
    print $cgi->start_form(-name=>'rctable',
                           -onsubmit=>"return validate_atleastone_rc_checked(this)");

    print $cgi->hidden(-name=>'rctype', -default=>$cgi->param('rctype'));
    print $cgi->hidden(-name=>'mode', -default=>"removerc");
                           
    print $cgi->start_table({-border => 1});
    print $cgi->start_Tr({-align=>'center', -valign=>'middle'});
    print $cgi->td("Select");
    print $cgi->td($cgi->a({-href=>"https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_node.html", 
                            -onClick=>"return popup('https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_node.html')"},
                           "NodeName"));
    print $cgi->end_Tr;

    foreach(@rcarray){
        print $cgi->start_Tr({-align=>'center', -valign=>'middle'});

        my $identifier = "$_->[0]"; # node_id in node table
        print $cgi->td($cgi->checkbox(-name=>"node.choice.$identifier",
                                      -checked=>0,
                                      -value=>1,
                                      -label=>'')); # selection checkbox
        print $cgi->td($_->[1].".".$_->[2]);
        
        $cgi->end_Tr();
    }

    print $cgi->end_table;
    print "<br>";
    print $cgi->submit(-value=>'Remove Selected Resources');
    print $cgi->end_form;
}

sub showManager {
    my ($cgi, $rctype, $rcname) = @_;

    # Query to selected database    	
    my $perldb = new PerlDB();
    my $query = "SELECT mgr_id, mgr_host, mgr_hostip
                 FROM rcmgr
                 WHERE mgr_host LIKE '$rcname'";
    my @rcarray = @{$perldb->multcol_select($query)};
    $perldb->db_end ;

    # Show resources in Form
    print $cgi->start_form(-name=>'rctable',
                           -onsubmit=>"return validate_atleastone_rc_checked(this)");

    print $cgi->hidden(-name=>'rctype', -default=>$cgi->param('rctype'));
    print $cgi->hidden(-name=>'mode', -default=>"removerc");
                           
    print $cgi->start_table({-border => 1});
    print $cgi->start_Tr({-align=>'center', -valign=>'middle'});
    print $cgi->td("Select");
    print $cgi->td($cgi->a({-href=>"https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_mgrfullname.html", 
                            -onClick=>"return popup('https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_mgrfullname.html')"},
                           "ManagerName"));
    print $cgi->td($cgi->a({-href=>"https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_headip.html", 
                            -onClick=>"return popup('https://$ENV{APACHE_SERVER}:$ENV{APACHE_PORT}/HPCALE_REPMAN/desc/desc_headip.html')"},
                           "ManagerIP"));
    print $cgi->end_Tr;

    foreach(@rcarray){
        print $cgi->start_Tr({-align=>'center', -valign=>'middle'});

        my $identifier = "$_->[0]"; # mgr_id in rcmgr table
        print $cgi->td($cgi->checkbox(-name=>"mgr.choice.$identifier",
                                      -checked=>0,
                                      -value=>1,
                                      -label=>'')); # selection checkbox
        print $cgi->td($_->[1]);
        print $cgi->td($_->[2]);
        
        $cgi->end_Tr();
    }

    print $cgi->end_table;
    print "<br>";
    print $cgi->submit(-value=>'Remove Selected Resources');
    print $cgi->end_form;
}

1;
