# Written by Il-Chul Yoon <iyoon@cs.umd.edu>

eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
    & eval 'exec perl -S $0 $argv:q'
    if 0;

use strict;
use warnings;
use Cwd;
use File::Path;

my ($errors, $warnings) = (0, 0);

&read_config ;
&check_env_vars ;
&create_directories ;
&install_html ; 
&install_cgi ;

print "\nInstallation finished ...\n";

sub read_config {
   open I, "< config";
   my @lines = <I>;
   close I;

   foreach(@lines){
      my $s = pack_line($_);
      next if (length($s) == 0);

      my @arr = split /\s+/, $s; 
      $ENV{$arr[0]} = $arr[1];
   }
}

sub pack_line {
   my $str = shift;

   chomp $str;
   $str =~ s/^\s+//;
   $str =~ s/\s+$//;
   return $str;
}

sub check_env_vars {
   my $chkresult = 1;

   print "\nChecking Environment Variables ...\n";
   my @envvars = qw/ APACHE_HOME 
                     HTDOCS_HOME 
                     APACHE_SERVER
                     APACHE_PORT
                     DB_SERVER
                     DB_PORT
                     DB_NAME
                     DB_USER
                     DB_PASSWD /;

   foreach(@envvars){
      if(chk_envvar($_) < 0){
         $chkresult = -1;
      }
   }

   if($chkresult < 0){
      print "Missing Environment Variable.\n";
      exit;
   }
   else{
      print "All necessary environment variables are defined.\n";
   }
}

sub chk_envvar {
   my $var = shift;
   if(!defined($ENV{$_})){
      print STDERR "Undefined environment variable: $var\n";
      return -1;
   }
   else{
      print STDERR "  Checking for $var....yes\n";
      return 1;
   }
}

# Create necessary directories
sub create_directories 
{
   print "\nRemoving previous directories ...\n";

   rmtree(["$ENV{HTDOCS_HOME}/HPCALE_REPMAN/desc"], 1, 1);
   rmtree(["$ENV{HTDOCS_HOME}/HPCALE_REPMAN/swdesc"], 1, 1);
   rmtree(["$ENV{APACHE_HOME}/cgi-bin/HPCALE_REPMAN"], 1, 1);
   
   print "\nCreating directories ...\n";

   mkpath(["$ENV{HTDOCS_HOME}/HPCALE_REPMAN/desc"], 1, 0711);
   mkpath(["$ENV{HTDOCS_HOME}/HPCALE_REPMAN/swdesc"], 1, 0711);
   mkpath(["$ENV{APACHE_HOME}/cgi-bin/HPCALE_REPMAN"], 1, 0711);
}

# Move html files and .js files
sub install_html {
   print "\nInstalling HTML files ...\n";
   
   print "\tInstalling description files ...\n";
   `cp -R ./html/desc   $ENV{HTDOCS_HOME}/HPCALE_REPMAN`;
   `cp -R ./html/swdesc $ENV{HTDOCS_HOME}/HPCALE_REPMAN`;
    
   my @list = glob("./html/*");
   
   # Move javascript files and html files. (excluding directories)
   foreach(@list){
      next if(-d $_);
      print "\tInstalling $_...\n";
      
      if($_ =~ /.+\.js/){
          `cp -v $_ $ENV{HTDOCS_HOME}/HPCALE_REPMAN`;
      }
      elsif($_ =~ /.+\.html/){
         open IN, "< $_";
         ($_ =~ m/.+\/(.+)/);
         open OUT, "> $ENV{HTDOCS_HOME}/HPCALE_REPMAN/$1";
         foreach(<IN>){
             $_ =~ s/\$ENV\{APACHE_SERVER\}/$ENV{APACHE_SERVER}/g;
             $_ =~ s/\$ENV\{APACHE_PORT\}/$ENV{APACHE_PORT}/g;
             print OUT $_;
         }
         close OUT;
         close IN;
      }
   }    
}

sub install_cgi {
   my $files= shift;
   print "\nInstalling CGI files ...\n";

   my @list = glob("./cgi-bin/*");
   
   # Move cgi-bin files
   foreach(@list){
      if($_ =~ /.+\/(.+)\.pl/){
         print "\tInstalling $_<$1>...\n";

         open IN, "< $_";
         open OUT, "> $ENV{APACHE_HOME}/cgi-bin/HPCALE_REPMAN/$1.cgi";

         print OUT "#!$ENV{PERL_PATH} -w\n";
         
         my @envvars = qw/ APACHE_HOME 
                           HTDOCS_HOME 
                           APACHE_SERVER
                           APACHE_PORT
                           DB_SERVER
                           DB_PORT
                           DB_NAME
                           DB_USER
                           DB_PASSWD /;

         # print environment variable
         print OUT "\n\n";
         foreach(@envvars){
            print OUT "   \$ENV\{$_\} = \"$ENV{$_}\";\n";
         }
         
         foreach(<IN>){
             $_ =~ s/\$ENV\{APACHE_SERVER\}/$ENV{APACHE_SERVER}/g;
             $_ =~ s/\$ENV\{APACHE_PORT\}/$ENV{APACHE_PORT}/g;
             print OUT $_;
         }
         close OUT;
         close IN;

         `chmod a+x $ENV{APACHE_HOME}/cgi-bin/HPCALE_REPMAN/$1.cgi`;
      }
      elsif($_ =~ /.+\/(.+)\.pm/){
         print "\tInstalling $_<$1>...\n";
         my $fname = $1;

         open IN, "< $_";
         open OUT, "> $ENV{APACHE_HOME}/cgi-bin/HPCALE_REPMAN/$1.pm";
         foreach(<IN>){
             $_ =~ s/\$ENV\{APACHE_SERVER\}/$ENV{APACHE_SERVER}/g;
             $_ =~ s/\$ENV\{APACHE_PORT\}/$ENV{APACHE_PORT}/g;

             if($fname eq "PerlDB"){
                $_ =~ s/\$ENV\{DB_SERVER\}/$ENV{DB_SERVER}/g;
                $_ =~ s/\$ENV\{DB_PORT\}/$ENV{DB_PORT}/g;
                $_ =~ s/\$ENV\{DB_NAME\}/$ENV{DB_NAME}/g;
                $_ =~ s/\$ENV\{DB_USER\}/$ENV{DB_USER}/g;
                $_ =~ s/\$ENV\{DB_PASSWD\}/$ENV{DB_PASSWD}/g;
             }

             print OUT $_;
         }
         close OUT;
         close IN;
      }
   }    
}

